@@ -27,8 +27,6 @@
 
 #define ARRAY_SIZE(a) (sizeof(a)/sizeof((a)[0]))
 
-#define MAX_USB_EVENTS 32
-
 /* max number of input events to read in one read call */
 #define MAX_EVENTS 50
 
@@ -39,10 +37,7 @@
 
 #include <xf86Xinput.h>
 #include <mipointer.h>
-
-#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 3
-# include <X11/Xatom.h>
-#endif
+#include <X11/Xatom.h>
 
 /******************************************************************************
  * Debugging support
@@ -148,11 +143,11 @@ extern int wcmDeviceTypeKeys(LocalDevicePtr local);
 
 /* hotplug */
 extern int wcmNeedAutoHotplug(LocalDevicePtr local, const char **type);
-extern void wcmHotplugOthers(LocalDevicePtr local);
+extern void wcmHotplugOthers(LocalDevicePtr local, const char *basename);
 extern int wcmAutoProbeDevice(LocalDevicePtr local);
 
 /* setup */
-extern int wcmParseOptions(LocalDevicePtr local);
+extern int wcmParseOptions(LocalDevicePtr local, int hotplugged);
 extern void wcmInitialCoordinates(LocalDevicePtr local, int axes);
 extern void wcmInitialScreens(LocalDevicePtr local);
 extern void wcmInitialScreens(LocalDevicePtr local);
@@ -163,8 +158,9 @@ extern int wcmDevSwitchMode(ClientPtr client, DeviceIntPtr dev, int mode);
 /* run-time modifications */
 extern void wcmChangeScreen(LocalDevicePtr local, int value);
 extern void wcmTilt2R(WacomDeviceStatePtr ds);
-extern void wcmFingerTapToClick(WacomCommonPtr common);
+extern void wcmGestureFilter(WacomDevicePtr priv, int channel);
 extern void wcmEmitKeysym(DeviceIntPtr keydev, int keysym, int state);
+extern void wcmSoftOutEvent(LocalDevicePtr local);
 
 extern void wcmRotateTablet(LocalDevicePtr local, int value);
 extern void wcmRotateCoordinates(LocalDevicePtr local, int* x, int* y);
@@ -175,14 +171,16 @@ extern int wcmCheckPressureCurveValues(int x0, int y0, int x1, int y1);
 extern int wcmGetPhyDeviceID(WacomDevicePtr priv);
 
 /* device properties */
-#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 3
 extern int wcmSetProperty(DeviceIntPtr dev, Atom property, XIPropertyValuePtr prop, BOOL checkonly);
 extern void InitWcmDeviceProperties(LocalDevicePtr local);
-#endif
 
 /* Device probing */
 int isdv4ProbeKeys(LocalDevicePtr local);
 int usbProbeKeys(LocalDevicePtr local);
 
+/* Utility functions */
+extern Bool is_absolute(LocalDevicePtr local);
+extern void set_absolute(LocalDevicePtr local, Bool absolute);
+
 /****************************************************************************/
 #endif /* __XF86WACOM_H */
