@@ -26,7 +26,10 @@
 #include <asm/types.h>
 #include <linux/input.h>
 #define MAX_USB_EVENTS 32
-#define WACOM_VENDOR_ID 0x056a  /* vendor ID on the kernel device */
+
+/* vendor IDs on the kernel device */
+#define WACOM_VENDOR_ID 0x056a
+#define WALTOP_VENDOR_ID 0x172F
 
 #define DEFAULT_SUPPRESS 2      /* default suppress */
 #define MAX_SUPPRESS 100        /* max value of suppress */
@@ -110,6 +113,18 @@ struct _WacomModel
 #define ERASER_ID		0x00000008
 #define PAD_ID			0x00000010
 
+#define WCM_PEN			0x00000001
+#define WCM_TPC			0x00000002
+#define WCM_1FGT		0x00000004
+#define WCM_2FGT		0x00000008
+#define WCM_STRIP		0x00000010
+#define WCM_RING		0x00000020
+#define WCM_DUALINPUT		0x00000040
+#define WCM_ROTATION		0x00000080
+#define WCM_LCD 		0x00000100
+
+#define TabletHasFeature(common, feature) (((common)->tablet_type & (feature)) != 0)
+
 #define ABSOLUTE_FLAG		0x00000100
 #define KEEP_SHAPE_FLAG		0x00000200
 #define BAUD_19200_FLAG		0x00000400
@@ -133,8 +148,6 @@ struct _WacomModel
 					 * tablet buttons besides the strips are
 					 * treated as buttons */
 /* get/set/property */
-#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 3
-
 typedef struct _PROPINFO PROPINFO;
 
 struct _PROPINFO
@@ -146,7 +159,6 @@ struct _PROPINFO
 	int nSize;
 	int nDefault;
 };
-#endif /* GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 3 */
 
 struct _WacomDeviceRec
 {
@@ -240,7 +252,7 @@ struct _WacomDeviceRec
 	int throttleValue;      /* current throttle value */
 
 	/* JEJ - filters */
-	int* pPressCurve;       /* pressure curve */
+	int pPressCurve[FILTER_PRESSURE_RES]; /* pressure curve */
 	int nPressCtrl[4];      /* control points for curve */
 	int minPressure;	/* the minimum pressure a pen may hold */
 
@@ -347,6 +359,17 @@ extern WacomDeviceClass gWacomISDV4Device;
 #define MAX_CHANNELS 2
 #define MAX_FINGERS  2
 
+typedef struct {
+	int wcmZoomDistance;	       /* minimum distance for a zoom touch gesture */
+	int wcmZoomDistanceDefault;    /* default minimum distance for a zoom touch gesture */
+	int wcmScrollDistance;	       /* minimum motion before sending a scroll gesture */
+	int wcmScrollDirection;	       /* store the vertical or horizontal bit in use */
+	int wcmScrollDistanceDefault;  /* default minimum motion before sending a scroll gesture */
+	int wcmGestureUsed;	       /* retain used gesture count within one in-prox event */
+	int wcmTapTime;	   	       /* minimum time between taps for a right click */
+	int wcmTapTimeDefault;         /* default minimum time between taps for a right click */
+} WacomGesturesParameters;
+
 struct _WacomCommonRec 
 {
 	/* Do not move wcmDevice, same offset as priv->name */
@@ -355,6 +378,7 @@ struct _WacomCommonRec
 	unsigned char wcmFlags;     /* various flags (handle tilt) */
 	int debugLevel;
 	int tablet_id;		     /* USB tablet ID */
+	int tablet_type;	     /* type (penabled/1FGT/2FGT, etc) of the tablet */
 	int fd;                      /* file descriptor to tablet */
 	int fd_refs;                 /* number of references to fd; if =0, fd is invalid */
 	unsigned long wcmKeys[NBITS(KEY_MAX)]; /* supported tool types for the device */
@@ -402,20 +426,22 @@ struct _WacomCommonRec
 	int wcmGesture;	     	     /* disable/enable touch gesture */
 	int wcmGestureDefault;       /* default touch gesture to disable when not supported */
 	int wcmGestureMode;	       /* data is in Gesture Mode? */
+	int wcmTouchpadMode;           /* in touchpad mode? */
 	WacomDeviceState wcmGestureState[MAX_FINGERS]; /* inital state when in gesture mode */
 	int wcmCapacity;	     /* disable/enable capacity */
 	int wcmCapacityDefault;      /* default to -1 when capacity isn't supported/disabled */
 				     /* 3 when capacity is supported */
+	WacomGesturesParameters wcmGestureParameters;
 	int wcmMaxCursorDist;	     /* Max mouse distance reported so far */
 	int wcmCursorProxoutDist;    /* Max mouse distance for proxy-out max/256 units */
 	int wcmCursorProxoutDistDefault; /* Default max mouse distance for proxy-out */
 	int wcmSuppress;        	 /* transmit position on delta > supress */
 	int wcmRawSample;	     /* Number of raw data used to filter an event */
-	int wcmScaling;		     /* dealing with missing calling DevConvert case. Default 0 */
 
 	int bufpos;                        /* position with buffer */
 	unsigned char buffer[BUFFER_SIZE]; /* data read from device */
 
+	void *private;		     /* backend-specific information */
 	int wcmLastToolSerial;
 	int wcmEventCnt;
 	struct input_event wcmEvents[MAX_USB_EVENTS];  /* events for current change */
